@@ -29,7 +29,7 @@ our @EXPORT = qw(
 
 );
 
-our $VERSION = '0.01_01';
+our $VERSION = '0.01_02';
 
 require XSLoader;
 XSLoader::load('AntTweakBar', $VERSION);
@@ -122,6 +122,13 @@ sub set_bar_params {
     }
 }
 
+sub set_variable_params {
+    my ($self, $variable, %params) = @_;
+    while (my ($k, $v) = each(%params)) {
+        _set_variable_parameter($self->{_bar_ptr}, $variable, $k, $v);
+    }
+}
+
 # Preloaded methods go here.
 
 1;
